==> apache-opennlp_1.9.2.orig.tar.gz: apache-opennlp-1.9.2-src/opennlp-tools/src/test/java/opennlp/tools/doccat/DocumentSampleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.doccat;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectInputStream;
import java.io.ObjectOutput;
import java.io.ObjectOutputStream;

import org.junit.Assert;
import org.junit.Test;

public class DocumentSampleTest {

  @Test
  public void testEquals() {
    Assert.assertFalse(createGoldSample() == createGoldSample());
    Assert.assertTrue(createGoldSample().equals(createGoldSample()));
    Assert.assertFalse(createPredSample().equals(createGoldSample()));
    Assert.assertFalse(createPredSample().equals(new Object()));
  }

  @Test
  public void testDocumentSampleSerDe() throws IOException {
    DocumentSample documentSample = createGoldSample();
    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
    ObjectOutput out = new ObjectOutputStream(byteArrayOutputStream);
    out.writeObject(documentSample);
    out.flush();
    byte[] bytes = byteArrayOutputStream.toByteArray();

    ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bytes);
    ObjectInput objectInput = new ObjectInputStream(byteArrayInputStream);

    DocumentSample deSerializedDocumentSample = null;
    try {
      deSerializedDocumentSample = (DocumentSample) objectInput.readObject();
    } catch (ClassNotFoundException e) {
      // do nothing
    }

    Assert.assertNotNull(deSerializedDocumentSample);
    Assert.assertEquals(documentSample.getCategory(), deSerializedDocumentSample.getCategory());
    Assert.assertArrayEquals(documentSample.getText(), deSerializedDocumentSample.getText());
  }

  public static DocumentSample createGoldSample() {
    return new DocumentSample("aCategory", new String[]{"a", "small", "text"});
  }

  public static DocumentSample createPredSample() {
    return new DocumentSample("anotherCategory", new String[]{"a", "small", "text"});
  }

}

==> apache-opennlp_2.1.0.orig.tar.gz: apache-opennlp-2.1.0-src/opennlp-tools/src/test/java/opennlp/tools/doccat/DocumentSampleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.doccat;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectInputStream;
import java.io.ObjectOutput;
import java.io.ObjectOutputStream;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class DocumentSampleTest {

  @Test
  void testEquals() {
    Assertions.assertFalse(createGoldSample() == createGoldSample());
    Assertions.assertTrue(createGoldSample().equals(createGoldSample()));
    Assertions.assertFalse(createPredSample().equals(createGoldSample()));
    Assertions.assertFalse(createPredSample().equals(new Object()));
  }

  @Test
  void testDocumentSampleSerDe() throws IOException {
    DocumentSample documentSample = createGoldSample();
    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
    ObjectOutput out = new ObjectOutputStream(byteArrayOutputStream);
    out.writeObject(documentSample);
    out.flush();
    byte[] bytes = byteArrayOutputStream.toByteArray();

    ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bytes);
    ObjectInput objectInput = new ObjectInputStream(byteArrayInputStream);

    DocumentSample deSerializedDocumentSample = null;
    try {
      deSerializedDocumentSample = (DocumentSample) objectInput.readObject();
    } catch (ClassNotFoundException e) {
      // do nothing
    }

    Assertions.assertNotNull(deSerializedDocumentSample);
    Assertions.assertEquals(documentSample.getCategory(), deSerializedDocumentSample.getCategory());
    Assertions.assertArrayEquals(documentSample.getText(), deSerializedDocumentSample.getText());
  }

  public static DocumentSample createGoldSample() {
    return new DocumentSample("aCategory", new String[] {"a", "small", "text"});
  }

  public static DocumentSample createPredSample() {
    return new DocumentSample("anotherCategory", new String[] {"a", "small", "text"});
  }

}
